# Enterprises are embracing AI. But can they secure it?
## Taking a confident approach to AI security and navigating the path to adoption.
## Information:

+ Link: https://www.cybersecuritydive.com/spons/enterprises-are-embracing-ai-but-can-they-secure-it/716362/
+ Source: CyberSecurity Dive
+ Author: Anand Oswal, Senior Vice President and General Manager of Network Security, Palo Alto Networks
+ Date published: 20 May 2024, 05:00
+ Date scraped: 20 May 2024, 14:02

## Article:
![Main article image](https://www.cybersecuritydive.com/imgproxy/K6B_R4K6GPsKZz01qxxyd9CZr24iwtLAuFuJsB8QBgc/g:ce/rs:fill:770:435:0/bG9jYWw6Ly8vZGl2ZWltYWdlL29zZC1haS1zZWN1cml0eS0xLnBuZw.webp)


AI offers an amazing opportunity to create new capabilities, richer experiences, and unprecedented economic opportunities.AI applications are already becoming ubiquitous in the workplace as employees are using GenAI applications to increase productivity and companies are developing AI-driven apps to transform business operations and customer experiences. A recent[Gartner](https://www.gartner.com/en/newsroom/press-releases/2023-10-11-gartner-says-more-than-80-percent-of-enterprises-will-have-used-generative-ai-apis-or-deployed-generative-ai-enabled-applications-by-2026)study predicted that, by 2026, more than 80% of enterprises will have used AI APIs or deployed generative AI applications. While these uses of AI can positively impact both your top and bottom line, they can also lead to massive risk if not properly secured.


* **Employees using third-party AI applications:**Today, there are thousands of GenAI tools available on the market and, the truth is, your employees are likely already using them to increase productivity. For example, your teams may be using image and video generation AI applications, or AI-powered note taking apps to transcribe meetings, and your developers might be using copilots and code optimization services to build products faster.
* **Enterprises building AI-powered applications:**Many enterprises are already starting to leverage AI to build a competitive edge. The business uses of GenAI apps in enterprises can include intelligent customer service chatbots, AI-powered language processing tools, human resources virtual help desks, fraud detection applications, virtual shopping assistants, intelligent energy management systems, and even bespoke machine learning models for business analytics.


In both cases, AI adoption comes with new risks that must be mitigated in order to safely adopt this new technology.


#### What are the risks?


The productivity gains that come from using third-party AI applications often leads employees to use these AI-powered apps without proper approval or oversight, posing a significant security risk for organizations. Take for example a marketing team using image and video generation AI applications to automatically create compelling new content. What happens when that marketing team uses a risky, unsanctioned app and the details of your confidential product launch leak? Or your developers may be using copilots and code optimization services to build products faster, but what if optimized code returned from that application included malicious scripts?


Similarly, as companies build AI into their operations and customer-facing channels, they face the daunting task of managing increasingly complex infrastructures – because integrating AI is about more than sticking an AI app to your existing infrastructure stack. AI requires a whole new, complex infrastructure to be adopted, increasing your attack surface. With AI models and datasets becoming increasingly valuable assets, organizations must implement resilient security measures to safeguard them from unauthorized access, manipulation, or theft. The choice is simple -- react to security incidents when they come, or secure these applications by design.


#### What are the solutions?


Whether your company is using AI tools as part of your work flows or building AI into your infrastructure stack, you must ensure that your enterprise’s use of AI issecured by design. Organizations must implement robust policies and procedures for evaluating, approving, and monitoring the use of AI applications. They must also invest in comprehensive AI security solutions that provide visibility into all AI usage across the enterprise, enabling proactive threat detection and response. Here are a few things to consider when starting your company’s journey to securely adopting AI: 


***Monitoring and Controlling for Employees’ AI use***


In order to effectively secure employees’ use of AI across the enterprise, security teams need visibility into what apps are being used, whether they are secure, what data is flowing in and out of them, whether anything sensitive is being leaked, and whether anything bad is coming in from those apps. They also need controls to enforce corporate security policies, limit access to confidential data, and prevent unauthorized users from viewing or modifying sensitive information. Security teams must also perform risk assessments and conduct continuous monitoring to detect and mitigate potential security risks and compliance issues. By continuously monitoring AI apps, organizations can identify anomalous behavior, unauthorized access attempts and data breaches in real-time, allowing them to take prompt corrective action and prevent additional damage.


***Secure by Design***


Securing AI infrastructure can be complex because building with AI models means you’re introducing a new AI tech stack, in addition to the components you would have deployed with a traditional application. Each new component of your AI app exposes new risks for attackers to exploit from the sourcing and/or building of AI components, to configuration, to runtime. Security considerations should be incorporated into every stage of the AI development lifecycle to mitigate potential risks and vulnerabilities.


***Understanding AI Usage***


The starting point for securing the AI-powered applications you might be building is to understand and govern the entire AI ecosystem, including models, applications and resources, to reduce the risk of data exposure and compliance breaches. Since AI introduces additional complexity above and beyond traditional applications, AI applications must be analyzed for both traditional, and AI-specific risks. As an example, identifying model misconfigurations and supply chain vulnerabilities can reduce model and application risks. Once identified, you must continuously monitor and implement proper governance controls around AI usage.


***Securing AI at Runtime***


Once risks from the software supply chain, configurations, and other weaknesses have been addressed, there is still the possibility that someone or something will target weakness in the application once the application is active and in production – and more vulnerable to malicious activity. For this, you must protect enterprise AI applications and LLMs from both traditional and AI-specific attacks at runtime. Real-time protection should extend across AI applications, AI models, and AI-related datasets, such as inference databases and training data.


***Platformization***


According to[recent studies](https://www.zdnet.com/article/the-more-cybersecurity-tools-an-enterprise-deploys-the-less-effective-their-defense-is/), the average company employs a staggering 45 cybersecurity tools. As each new technology wave takes hold, enterprises have expanded the tools that they use with yet another point product to solve for new risks associated with that technology. But this rapid expansion hasn’t solved the problem, it’s created a convoluted mess of tools that have led to undue fragmentation and interoperability issues. It is far more effective for companies to be proactive in their approach to building a thoughtful infrastructure through a platformized approach.


Platformization can fundamentally change how enterprises approach AI security by centralizing efforts within existing cybersecurity platforms. This will enable enterprises to manage AI security alongside other cybersecurity functions, such as network security, endpoint protection, and cloud security. Implementing this centralized approach allows security teams to monitor and mitigate threats more effectively, minimizing the risk of security breaches and data loss.


By integrating all these best practices into the AI development lifecycle, organizations can effectively secure their AI operations.


#### Looking Ahead


When it comes to securing your organization’s use of AI – you must take a secure-by-design approach by baking security into your AI adoption journey from designing, to planning, building and running. Safeguarding your digital assets is a non-negotiable – because when it comes to AI digital transformation, it’s important to use proactive defense strategies and adopt a holistic approach to cybersecurity. This includes integrated security solutions that provide end-to-end visibility, centralized management, and automated threat detection and response capabilities.


By taking necessary and thoughtful steps to secure AI usage and infrastructure, you can fully realize the potential benefits of AI in giving your company the competitive edge.





## Tags:


### Autogenerated tags:
apps ai-powered teams cybersecurity genai
