# Harnessing the Power of CTEM for Cloud Security
## Tired of chasing endless vulnerabilities? Enter Continuous Threat Exposure Management (CTEM). Prioritize critical exposures, streamline remediation, a
## Information:

+ Link: https://thehackernews.com/2024/04/harnessing-power-of-ctem-for-cloud.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 02 April 2024, 16:57
+ Date scraped: 02 April 2024, 12:12

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhmlElpcU83vt-eWmC6r_P_mRpyJm-uvxUQCEPB5edZQUuOyTOSWf0cZWWs0dA7rPxDotTAQbBenAG_Jzhofh0z9pa08-T0T72yar4vIO84dqjiV2oISJmGh26qOaxoFxS4B1VmPPJe2eDJxLNi0XzIJXyjVPixlC7HRY10aMzoUWYpPEuRv0j7VoE1u3c/s728-rw-e365/xmcyber.jpg)


Cloud solutions are more mainstream – and therefore more exposed – than ever before.


In 2023 alone, a staggering 82% of data breaches were against public, private, or hybrid cloud environments. What's more, nearly 40% of breaches spanned multiple cloud environments. The average cost of a cloud breach was above the overall average, at $4.75 million. In a time where cloud has become the de facto standard – with 65% of IT decision-makers confirming that cloud-based services are their first choice when upgrading or purchasing new solutions – despite its overwhelming prominence, cloud security still faces multiple challenges.


Security Challenges in the Cloud [#](#security-challenges-in-the-cloud)
-----------------------------------------------------------------------


One major hurdle is the lack of visibility. Unlike physical servers you can see and touch, cloud resources are often spread across vast networks, making it difficult to monitor for suspicious activity and leaving vulnerabilities undetected. Another challenge is the inconsistency across cloud vendor permission management systems. Different providers have different controls for who can access and modify data. This inconsistency creates complexity and increases the risk of accidental misconfigurations, which are a leading cause of breaches.


Moreover, with multiple teams involved in cloud deployments – development, operations, security – clear ownership and accountability for cloud security can be blurred. This lack of coordination can lead to situations where security best practices are overlooked or bypassed. Additionally, many attacks move across the cloud to on-prem environments and vice versa, which can put both environments at risk.


All these challenges highlight the urgent need for robust cloud security solutions that provide comprehensive visibility, standardized permission management, and clear lines of responsibility. Yet security resources are stretched thin even in the best-provisioned teams – and cloud security teams are expected to investigate and remediate thousands of exposures that may not all have the same impact on critical resources. This leads to uncertainty around what to fix first and how to actually address all the identified exposures, leaving cloud environments exposed to cyberattacks.


Continuous Exposure Management is Essential [#](#continuous-exposure-management-is-essential)
---------------------------------------------------------------------------------------------


Instead of chasing countless vulnerabilities, security teams need to prioritize the most critical ones. This means being able to quickly identify the most dangerous attack paths and take preemptive action against advanced attack methods in the cloud.


By focusing on high-risk areas, cloud security teams can build targeted remediation plans that prevent major attacks, streamline workflows, and accurately report on real threats across multiple cloud environments. The key to achieving this is [Continuous Threat Exposure Management](https://xmcyber.com/ctem/?utm_medium=sponsorarticle&utm_source=hackernews&utm_campaign=ctem-for-cloud-security) (CTEM), a proactive and continuous five-stage program or framework that reduces exposure to cyberattacks. First introduced by [Gartner in 2022](https://info.xmcyber.com/top-strategic-technology-trends-for-2024-continuous-threat-exposure-management?utm_medium=sponsorarticle&utm_source=hackernews&utm_campaign=ctem-for-cloud-security), CTEM has proven essential for preventing high-impact attacks, improving remediation efficiency, and reporting true risk. 


  CTEM was introduced to solve the problem of endless lists of exposures, and more specifically vulnerabilities, across on-prem environments. Not being able to highlight and fix the exposures that are most critical leaves security teams fixing CVEs that may or may not be exploitable or impactful in their specific environment. In multi-cloud environments, the lists of vulnerabilities may be shorter, but together with misconfigurations and highly privileged access, they add up to a long list of exposures that attackers can use to breach the multi-cloud environment and that security teams must address. The only way to block attacks is by identifying and fixing the exposures with the highest impact on your business. That requires adopting the CTEM framework in the cloud environment.


Fix What Matters Across Multi-Cloud[#](#fix-what-matters-across-multicloud)
---------------------------------------------------------------------------


To help cloud security teams fix what matters and block high-impact attacks in multi-cloud environments, a comprehensive CTEM program will highlight the most impactful entities that can compromise cloud resources. These solutions identify the cloud resources that can be compromised and discover all the exposures that attackers can use to compromise them. Mapping the attack paths that attackers could exploit helps prioritize and validate the most impactful exposures that are exploitable in the multi-cloud environment in order to address them first.


For example, taking the attacker's perspective allows identifying top choke points. Choke points are critical weaknesses in your cloud defenses, where multiple attack paths converge on a single exposure. They can be easily breached by attackers who can then access a vast network of resources – databases, computers, identity controls, and more. By prioritizing these high-impact areas, security teams focus on the most attractive targets for attackers, maximizing the return on their security efforts. Common choke points include internet-facing systems and unused access accounts. Addressing them significantly reduces the attack surface, effectively fortifying your entire cloud environment.


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjN5kjn8PrjpPmSFshUd8Fyl1sgvuQ4ychS8UYmuZlzLpBhreZuBIhMR9vWoNtMDYBtH4l0ArylmGD14HQCCCqEsOiMZz-G1Kz3M6TGYGvtfXHv-slHd4BDJueKdzJh_BUgVsPhOhRRktnpDgSVMsSEoqNZSh15hYD-ySlzFO1y0ksH9JfUCBrCtAiJsAc/s728-rw-e365/Cloudchokepoint1.png)
Another example of a high-impact exposure stems from pre-defined highly-privileged access. Highly privileged accounts, like pre-defined admins, are considered "game-over" assets. If compromised, attackers can wreak havoc. Having a comprehensive approach to CTEM helps by identifying these accounts and uncovering weaknesses that could leave them vulnerable. This includes spotting admin access without multi-factor authentication (MFA) or unused service accounts – essentially; weaknesses attackers would love to exploit.


To ensure critical exposures are addressed, advanced exposure management solutions provide remediation guidance and alternatives. More often than not highly privileged accounts or internet-facing resources cannot be restricted, but analyzing the attack path that leads to them makes it possible to find a fix that lowers their exploitability and hence their level of risk.


Stopping Hybrid Environment Attacks [#](#stopping-hybrid-environment-attacks)
-----------------------------------------------------------------------------


Attackers are not limited by hybrid environments, and defenders must ensure they too are not limited. Solutions that analyze [hybrid attack paths](https://info.xmcyber.com/the-power-of-attack-graphs-in-cloud?utm_medium=sponsorarticle&utm_source=hackernews&utm_campaign=ctem-for-cloud-security), across on-prem and multi-cloud environments allow security teams to stay one step ahead of attacks – understanding exactly where they are exposed to cyber threats. These tools provide complete details around potential breach points, attack techniques, permissions usage, and remediation alternatives to help customers address these exposures and block the most critical attack paths. 


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgyZS9oxfKEZ-yHTcMRUwiKY8HU72i4uFqwZt4Y7SYHIABFMrRhILEtnqwobTTiBs5IaF1x1ya0i25w3IRr0UxIewR77LQrDp57HNn-r2EKsheCtax1tS_NQIkiAMNkvP26Myy4AfvPbq0zp57Qi_cpyRKzSycTF3E7brZHjzwZMtxaxjmo7yazikpmDYY/s728-rw-e365/Cloudchokepoint_2.png)
Summary[#](#summary)
--------------------


While traditional cloud security struggles against the volume of ever-present exposures, CTEM offers an actionable remediation plan by focusing on the most critical ones in a specific environment. The right approach to CTEM reaches across on-prem and multi cloud, encompassing your entire IT landscape. This holistic approach eliminates blind spots and empowers organizations to transition from reactive to proactive defense. By embracing CTEM, organizations can ensure their success in the cloud-based future.


***Note:** This expertly contributed article is written by Zur Ulianitzky, VP Security Research at XM Cyber.*


  





## Tags:


### Autogenerated tags:
cloud teams ctem multi-cloud on-prem high-impact
