# Identity Threat Detection and Response: Rips in Your Identity Fabric
## Unlock the power of Identity Threat Detection & Response (ITDR) to defend against sophisticated SaaS threats.
## Information:

+ Link: https://thehackernews.com/2023/08/identity-threat-detection-and-response.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 14 August 2023, 16:43
+ Date scraped: 14 August 2023, 12:00

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjlTo3sJsf6wMyu9NklrLsg-JigtVuLHN1qRLfLSVlAwDYp-FssfHj_t8OvoppCJ3e8JZUf_nrwU-sBwlsxiomhzPZEI7Ibiz-PITEygmLSO1MFmudbMQQwmJmVgfOQx0TMlz8Ed-WrFuXt4msCZGgk6au0981-uZxtEJgiLGsfMEibTIsuIekNIAL1zWPu/s728-e3650/itdr.jpg)


## Why SaaS Security Is a Challenge[#](#why-saas-security-is-a-challenge)


In today's digital landscape, organizations are increasingly relying on Software-as-a-Service (SaaS) applications to drive their operations. However, this widespread adoption has also opened the doors to new security risks and vulnerabilities.


The SaaS security attack surface continues to widen. It started with managing misconfigurations and now requires a holistic approach to handling the entire SaaS ecosystem. This includes the continuous monitoring and management of user access, roles and permissions, 3rd party apps installed by users, risks deriving from SaaS user devices and Identity Threat Detection & Response (ITDR).


There are a variety of reasons that SaaS security is so complex today. Firstly, there are a diverse range of applications, each having its own UI and terminology. And those environments are dynamic, from SaaS vendors understanding the importance of security and continually enhancing their applications with modern security measures to the ever-evolving user governance required such as onboarding, deprovisioning, adjustments in user access. These controls are effective only when continuously governed, for each app and each user. If that's not enough, these apps are managed by dispersed business departments, making it almost impossible for the security team to implement their security policies.


## ITDR Explained[#](#itdr-explained)


To address the Identity Threat Detection & Response challenge within the SaaS ecosystem, SaaS security solutions need a powerful solution that detects and responds to identity-related security threats based on key Indicators of Compromise (IOCs) and User and Entity Behavior Analytics (UEBA). These indicators provide forensic signs of a potential breach, such as malware, data breaches, unusual behavior, and other suspicious events.


ITDR is designed to tackle various SaaS-related threats, including password-based attacks, IP behavior anomalies, account-based detection, OAuth-based attacks, unauthorized document access, unusual user agent activities, and more. By offering a comprehensive suite of protective measures, organizations must proactively defend their SaaS stack and ensure the integrity of their sensitive data.


When it comes to dealing with SaaS threats, existing threat detection and identity management methods don't go far enough. Today's SaaS environments are complex and ITDR capabilities within these landscapes require deep knowledge and proven expertise.


Maor Bin, Co-Founder and CEO at Adaptive Shield had this to say about the new iteration of SaaS-ITDR, "Existing ITDR solutions focus on Endpoint and Active Directory protection and do not layer the complex SaaS environment. On-prem Active Directory will soon become a legacy technology and as on-prem is shifting to SaaS, this will recreate a gap in identity security posture management in SaaS apps."


This gap that Bin mentions is critical for SaaS security solutions to close and that is why Adaptive Shield has taken strides and brought out capabilities to do just that.


[**Learn more about ITDR and other core use cases to strengthen your SaaS security**](https://www.adaptive-shield.com/?utm_source=thehackernews&utm_medium=sponsored_content&utm_campaign=thn_itdr_2)


## Critical ITDR Capabilities for SaaS Ecosystems[#](#critical-itdr-capabilities-for-saas-ecosystems)


Your ITDR should be built on the foundation of a deep understanding of SaaS characteristics and Identity Governance within this landscape. Make sure you select a solution that is based on a very broad coverage of SaaS applications, who deeply understands the SaaS world and delivers accurate threat detection through contextualization of a variety of sources and events.


As a means of prevention and first layer of defense, the SSPM operates as the security layer in the Identity Fabric to establish robust user governance. This includes excessive permissions, access entitlement, user deprovisioning, and more, across the entire SaaS stack. Organizations should gain deep and consolidated visibility and control of user accounts, roles, permissions, privileged users, and activities.


As a second layer of threat protection, your SaaS security solution, like Adaptive Shield, ITDR capabilities provide extensive coverage in detecting anomalies and Tactics, Techniques, and Procedures (TTPs). By focusing on context and creating user and company profiles, it increases the accuracy of these detection alerts. Additionally, understanding expected behavior patterns and considering factors such as user access, permissions, and devices, enables the solution to better understand and prioritize alerts.


![Identity Threat Detection and Response](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgS7R82M7n_NMTajD41fbsNLxK__mGs3zguM-Dbwpgo3YCwZVbRc4wKho5kefr9gMHMqRzxR6pdUV22xXi3eSwYn5xnX0w29FcEFHab7Z-FYAfHFqw0THznR303AQoF37IfQfvCN3NWwwaIS4uyCwSRufsLuDkf9EoYknqkxILnJTmFfgw9iyqJZjoKNv2S/s728-e3650/threat-2.jpg)
![Identity Threat Detection and Response](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiy-SuruwAdFmxu7ss7rmImWwOLngekDXNKBaEAO36ILcHEWMRfaTGG3YI1O0GcfSZa8mMZJSnhvnUSs_FytE-IIxTpbP1HJZ-Aoxp-13bhaKllwMWiFC3h7rnd2Ha1SfXqNJAQMEHzuSt5XtgwAuNRD4pdJGOjIQ0gv_2rDEk0_gr7_eNDunDw6mCof2LH/s728-e3650/threat-1.jpg)
### **Key Capabilities Include:**[#](#key-capabilities-include)


1. **Tactics, Techniques, and Procedures (TTP):** Identification of common tactics and techniques that adversaries use to compromise systems, steal data, or disrupt operations. By understanding these TTPs, ITDR improves incident response capabilities through:
* **Indicator of Compromise (IOC) Detection**: Collection of evidence indicating that the organization's SaaS apps are under attack or have been compromised. IOCs can include data from IP addresses, domain names, URLs and more.
* **User and Entity Behavior Analytics (UEBA)**: Detection of behavioral anomalies, Adaptive Shield's ITDR can identify threat actors as they navigate through the organization's applications, offering proactive threat detection.

3. MITRE ATT&CK Mapping: Enhance incident response capabilities and improve threat detection and mitigation by aligning observed or potential attack techniques with the MITRE ATT&CK framework.
4. Alerts and Notifications: Get alerts in multiple channels such as email, Slack, or Teams, indicating potential security incidents or suspicious activities that require immediate investigation or response.
5. SIEM and SOAR Integrations: Seamlessly integrate with your existing Security Operations Center (SOC) and Security Orchestration, Automation, and Response (SOAR) tools, improving threat correlation and incident response efficiency.
6. Remediation Guidance: Get actionable recommendations and step-by-step guidance to address and mitigate vulnerabilities, weaknesses, or compromises in the event of a security incident.


## Comprehensive Security Management[#](#comprehensive-security-management)


When securing your SaaS environments, ensure your security platform goes beyond identity threat detection and response. Your solution should include a range of capabilities that strengthen your overall security management and offer a holistic prevention model for securing the SaaS Identity Fabric:

 * Misconfiguration Management: Identify security drifts across all security controls and receive detailed remediation plans to ensure proper configuration and prevent log-related threats.
* Identity and Access Governance: Consolidate visibility of user accounts, permissions, and activities across all SaaS applications, enabling effective risk management and ensuring appropriate access levels. Detect and mitigate the risks associated with disabled or dormant accounts.
* SaaS-to-SaaS Access and Discovery: Gain visibility into connected apps, legitimate or malicious, and assess the level of risk they pose to your SaaS environment.
* Device-to-SaaS Risk Management: Gain context and visibility to effectively manage risks originating from SaaS users and their associated devices.


With unparalleled insights and an array of features, Adaptive Shield empowers organizations to protect their SaaS stack, prevent data breaches, and safeguard their SaaS data from emerging threats.


[**Get a 15-minute demo to see how you can secure your entire SaaS stack**](https://www.adaptive-shield.com/lp/request-a-demo?utm_source=thehackernews&utm_medium=sponsored_content&utm_campaign=thn_itdr_3)



\_linkedin\_partner\_id = "2426929";
window.\_linkedin\_data\_partner\_ids = window.\_linkedin\_data\_partner\_ids || [];
window.\_linkedin\_data\_partner\_ids.push(\_linkedin\_partner\_id);

(function(l) {
if (!l){window.lintrk = function(a,b){window.lintrk.q.push([a,b])};
window.lintrk.q=[]}
var s = document.getElementsByTagName("script")[0];
var b = document.createElement("script");
b.type = "text/javascript";b.async = true;
b.src = "https://snap.licdn.com/li.lms-analytics/insight.min.js";
s.parentNode.insertBefore(b, s);})(window.lintrk);


![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8Xw8AAoMBgDTD2qgAAAAASUVORK5CYII=)



&#160;&#160;window.dataLayer = window.dataLayer || [];
&#160;&#160;function gtag(){dataLayer.push(arguments);}
&#160;&#160;gtag('js', new Date());&#160;&#160;gtag('config', 'AW-616997677');


&#160;&#160;!function(f,b,e,v,n,t,s)
&#160;&#160;{if(f.fbq)return;n=f.fbq=function(){n.callMethod?
&#160;&#160;n.callMethod.apply(n,arguments):n.queue.push(arguments)};
&#160;&#160;if(!f.\_fbq)f.\_fbq=n;n.push=n;n.loaded=!0;n.version='2.0';
&#160;&#160;n.queue=[];t=b.createElement(e);t.async=!0;
&#160;&#160;t.src=v;s=b.getElementsByTagName(e)[0];
&#160;&#160;s.parentNode.insertBefore(t,s)}(window, document,'script',
&#160;&#160;'https://connect.facebook.net/en\_US/fbevents.js');
&#160;&#160;fbq('init', '726907529044472');
&#160;&#160;fbq('track', 'PageView');

![The Hacker News]()
  





## Tags:


### Autogenerated tags:
saas itdr apps
