# Understanding Active Directory Attack Paths to Improve Security
## Discover the Dark Secrets of Active Directory Security. Uncover the Top Attack Paths & Vulnerabilities Used by Cybercriminals. Download the Research
## Information:

+ Link: https://thehackernews.com/2023/08/understanding-active-directory-attack.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 08 August 2023, 15:18
+ Date scraped: 08 August 2023, 10:01

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjD9C0REN7KC6ag9HZxtJmdBhb9jhG9qu-g1o0-d5pgvO87fXMVbkeFyD-e4ogIOt-9vMq6ueyzRf1qUPX5jCxh9NsnPp2HfzpVmn04QeSP0B9WDoDdtwSlv8pQPG38YWWOjBlw1HEFuUbzjwvQk_gOiqk8bB6ASMiOM9UEwomOq-KuxHuVlmMzBvnc48Y/s728-e365/cover.png)


Introduced in 1999, Microsoft Active Directory is the default identity and access management service in Windows networks, responsible for assigning and enforcing security policies for all network endpoints. With it, users can access various resources across networks. As things tend to do, times, they are a'changin' – and a few years back, Microsoft introduced Azure Active Directory, the cloud-based version of AD to extend the AD paradigm, providing organizations with an Identity-as-a-Service (IDaaS) solution across both the cloud and on-prem apps. (Note that as of July 11th 2023, this service was renamed to *Microsoft Entra ID*, but for the sake of simplicity, we'll refer to it as Azure AD in this post)


Both Active Directory and Azure AD are critical to the functioning of on-prem, cloud-based, and hybrid ecosystems, playing a key role in uptime and business continuity. And with 90% of organizations using the service for employee authentication, access control and ID management, it has become the keys to the proverbial castle.


## Active Directory, Actively Problematic[#](#active-directory-actively-problematic)


But as central as it is, Active Directory security posture is [often woefully lacking.](https://xmcyber.com/blog/2023-time-to-secure-active-directory-and-azure-ad/?utm_medium=sponsorarticle&utm_source=hackernews&utm_campaign=ad)


Let's take a quick peek at how Active Directory assigns users, which will shed some light on why this tool has some shall we say, issues, associated with it.


At the core, what Active Directory does is establish groups that have roles and authorizations associated with them. Users are assigned a username and password, which is then linked to their Active Directory Account Object. Using Lightweight Directory Access Protocol, passwords are verified as correct or incorrect and the usergroup is also verified. In general, users are assigned to the Domain User group and will be granted access to the objects that domain users have authorization to access. Then there are Admins – these are users assigned to the Domain Admins group. This group is highly privileged and is thus authorized to perform any actions in the network.


With such potentially potent capabilities, it's super critical to ensure that Active Directory is managed and configured optimally. Issues like missed patches, poor access management and misconfigurations can allow attackers to access even the most sensitive systems, which can have dire consequences.


In 2022, our in-house research found that 73% of the top attack techniques used in the compromising of critical assets involved mismanaged or stolen credentials – and more than half of the attacks in organizations include some element of Active Directory compromise. And once they have a foothold in Active Directory, attackers can perform loads of different malicious actions like:


* Hiding activity in the network
* Executing malicious code
* Elevating privileges
* Getting into the cloud environment to compromise critical assets


Point is, if you don't know what's happening in your Active Directory, and if you're lacking the proper processes and security controls, you're likely leaving the door wide open to attackers.


 
## Active Directory Attack Paths [#](#active-directory-attack-paths)


From an attacker's POV, Active Directory serves as a [great opportunity for conducting lateral movement,](https://xmcyber.com/blog/chaining-together-active-directory-attack-techniques-to-give-your-organization-the-edge-against-attackers/?utm_medium=sponsorarticle&utm_source=hackernews&utm_campaign=ad) as gaining that initial access allows them to move from a low-privileged user to a more valuable target – or even to fully take over – by exploiting misconfigurations or overly excessive permissions. 


So now let's take a look into the anatomy of 3 actual Active Directory attack paths and see how attackers made their way through this environment.


Here is an attack path we came across in one of our customer's environment:


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgsJg9AdmQ1S80AhT7vvaP8NryfyZlo8WfRf7A40IUAijCm9mgGLLTvp_HR1_FLIgwuaVtn2sB1WLs94zMM8qs3YHCNFFBHOtIhmbeD91B5awTeRdrWfidV_uVDBELVbmwzhtRXZtOA2GKrImw_wbSwvq7oIPnfXUVo3bToO_1CdGaVLmCNxUKPosmqQYI/s728-e365/AttackGraphA.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgsJg9AdmQ1S80AhT7vvaP8NryfyZlo8WfRf7A40IUAijCm9mgGLLTvp_HR1_FLIgwuaVtn2sB1WLs94zMM8qs3YHCNFFBHOtIhmbeD91B5awTeRdrWfidV_uVDBELVbmwzhtRXZtOA2GKrImw_wbSwvq7oIPnfXUVo3bToO_1CdGaVLmCNxUKPosmqQYI/s728-e365/AttackGraphA.png)
The organization was deeply committed to hardening their security posture but Active Directory was a blind spot. In this case, all authenticated users – essentially any users at all – in the domain had been accidentally granted the right to reset passwords. So if an attacker took over one Active Directory user via phishing or other social engineering techniques, they could then reset any passwords for other users and take over any account in the domain.Once they saw this, they finally understood their Active Directory security approach needed to level-up so they locked down and hardened their security practices.


Here's another one from one of our customer's Active Directory;


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiU2E0L3qm2hSQfNpjUfNrcMPNKId327TohLAP68MleGsr4wR2U9_0O056-Z-cI2nSNPBM0rj9D_A5xxR3uv6nwNxxyjfc_qc40xfyB_k2tmXdm_HZixAMxJLgH71C_EdRIQyX7PojOh7yyT9YKTMGuKVk8VyW01_gyZAcO-XiWF8n-zml1bV-gw36_bi0/s728-e365/AttackGraphB.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiU2E0L3qm2hSQfNpjUfNrcMPNKId327TohLAP68MleGsr4wR2U9_0O056-Z-cI2nSNPBM0rj9D_A5xxR3uv6nwNxxyjfc_qc40xfyB_k2tmXdm_HZixAMxJLgH71C_EdRIQyX7PojOh7yyT9YKTMGuKVk8VyW01_gyZAcO-XiWF8n-zml1bV-gw36_bi0/s728-e365/AttackGraphB.png)
We uncovered an attack path using the authenticated users group with permissions to change the GPO policy's gPCFileSysPath to a path with malicious policies.


One of the affected objects was the AD User Container, with a child object that was a user which was part of the Domain Admin group. Any user in the domain could get Domain Admin permissions -- all they needed was one non-privileged user to fall prey to a phishing email to compromise the entire domain. This could have led to a complete compromise of their domain.


Ready for one more? Here it is:


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEh6iUbp0HANOf8zND3jAETmMBOwE7HFWLCVCLZ1KSaUDSkLKBjXxFWLOoPGgdW_KZGvtTNBMd-FD-WhF2INAxHAoAvcYqqWap3KIXutkguhxR4N0wpFsIhJngvAjOMblqGgUU1Ej6ruBXAn8MOcZ3fF8Fy61M3qbGDfmFj6D_INN4yCHc0xjMXuipjDV60/s728-e365/AttackGraphC.png)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEh6iUbp0HANOf8zND3jAETmMBOwE7HFWLCVCLZ1KSaUDSkLKBjXxFWLOoPGgdW_KZGvtTNBMd-FD-WhF2INAxHAoAvcYqqWap3KIXutkguhxR4N0wpFsIhJngvAjOMblqGgUU1Ej6ruBXAn8MOcZ3fF8Fy61M3qbGDfmFj6D_INN4yCHc0xjMXuipjDV60/s728-e365/AttackGraphC.png)
This one starts with an attacker infiltrating an enterprise environment via phishing mail that when opened, executed code using a vulnerability on an unpatched machine. The next step exploited the compromised Active Directory user's local and domain credentials through credential dumping techniques. The attacker then had the permissions to add themselves to a group so they could add the compromised Active Directory user to an Active Directory helpdesk group.


The helpdesk group had the Active Directory permissions to reset other users passwords and at this stage, the attacker could reset a password to another user, preferably an old, out of use admin. Now that they were an admin, they could perform lots of harmful activities in the network, such as running malicious code by adding a script logon to other users in Active Directory.


These are just some relatively simple ways attackers make their way across Active Directory environments. By understanding these actual real-world attack paths, organizations can start to see what their Active Directory and AD Azure environments look like from the attacker's point of view.


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiAZ4sHPKqNZo3Eq87D2h4g6Ur3kBE9Ty5PLRXENhcnlEuHt4CZA_zIg6Lv15_f1ZgQHenAlyXSArlsIIzzN_2rXxYUO8PwtoJFi4wtTbQwcoJUtSuVelG_4fBTx-Z-x_r9KiNZ3VvefNYpl2gzBb51aL_Z3GWZ7I_Joo9JEu0Otqua-ujnN6bQchUcK8c/s728-e365/webinar.png)](https://info.xmcyber.com/active-directory-security?utm_medium=sponsorarticle&utm_source=hackernews&utm_campaign=ad)
#### Watch on-demand [How To Overcome Active Directory Exploits And Prevent Attacks](https://info.xmcyber.com/active-directory-security?utm_medium=sponsorarticle&utm_source=hackernews&utm_campaign=ad) to learn:[#](#watch-ondemand-how-to-overcome-active-directory-exploits-and-prevent-attacks-to-learn)


* How Active Directory (AD) exposures combined with other attack techniques form attack paths
* What kind of actions the attacker can perform once they compromise an AD user
* What to do for better Active Directory Security


## Conclusion[#](#conclusion)


Looking at attack paths can help shore up these potentially tricky environments. By getting a comprehensive view of the attack paths that exist in Active Directory across on-prem and cloud environments, organizations can learn how attackers move laterally with a context-based understanding of their environment – giving them visibility into how issues can combine to facilitate attacks and impersonate users, escalate privileges, and gain access to cloud environments.


With this understanding, organizations can prioritize what really needs fixing and harden environments to prevent Active Directory weaknesses from being leveraged by threat actors.


  





## Tags:


### Autogenerated tags:
cloud microsoft on-prem phishing
