# Why Are Compromised Identities the Nightmare to IR Speed and Efficiency?
## Discover how Silverfort's Unified Identity Protection Platform revolutionizes Incident Response by swiftly detecting compromised accounts and bolsteri
## Information:

+ Link: https://thehackernews.com/2024/02/why-are-compromised-identities.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 12 February 2024, 15:30
+ Date scraped: 12 February 2024, 11:02

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgc2WSwZk5dsXN4T1vBqab5c9yHRw1GzmDyK9e7CvxOvvLD6AbUolGHoWoITdPghnQtju4YYBXn3yTVes0zUJWgu7oJ_scastCzcCv4_5YrC0BL1wB4eIgPFnKDgab7t-cMgEHYjESMOy7f1_vMoBB5jiIxuLYbhtCr65HyiGZRQnR06teo1C7QZbv0b9o/s728-rw-e30/lock.jpg)


Incident response (IR) is a race against time. You engage your internal or external team because there's enough evidence that something bad is happening, but you're still blind to the scope, the impact, and the root cause. The common set of IR tools and practices provides IR teams with the ability to discover malicious files and outbound network connections. However, the identity aspect - namely the pinpointing of compromised user accounts that were used to spread in your network - unfortunately remains unattended. This task proves to be the most time-consuming for IR teams and has become a challenging uphill battle that enables attackers to earn precious time in which they can still inflict damage.


In this article, we analyze the root cause of the identity of IR blind spots and provide sample IR scenarios in which it acts as an inhibitor to a rapid and efficient process. We then introduce Silverfort's Unified Identity Protection Platform and show how its real-time MFA and identity segmentation can overcome this blind spot and make the difference between a contained incident and a costly breach.


IR 101: Knowledge is Power. Time is Everything [#](#ir-101-knowledge-is-power-time-is-everything)
-------------------------------------------------------------------------------------------------


The triggering of an IR process can come in a million shapes. They all share a resemblance in that you think – or are even sure – that ***something*** is wrong, but you don't know exactly ***what*, *where*, and *how*.** If you're lucky, your team spotted the threat when it's still building up its power inside but hasn't yet executed its malicious objective. If you're *not* so lucky, you become aware of the adversarial presence only after its impact has already broken out – encrypted machines, missing data, and any other form of malicious activity. 


That way or the other, the most urgent task once the IR starts rolling is to dissolve the darkness and get clear insights into the compromised entities within your environment. Once located and validated, steps can be taken to contain the attacks by quarantining machines, blocking outbound traffic, removing malicious files, and resetting user accounts.


As it happens, the last task is far from trivial when dealing with compromised user accounts and introduces a yet unaddressed challenge. Let's understand why that is.


### Identity IR Gap #1: No Playbook Move to Detect Compromised Accounts[#](#identity-ir-gap-1-no-playbook-move-to-detect-compromised-accounts)


Unlike malware files or malicious outbound network connections, **a compromised account doesn't do anything that is essentially malicious – it merely logs in to resources in the same manner a normal account would.** If it's an admin account that accesses multiple workstations and servers on a daily basis – which is the case in many attacks – its lateral movement won't even seem anomalous. 


Want to learn more about the Silverfort platform's Incident Response capabilities? [Schedule a demo today](https://www.silverfort.com/request-a-demo/?utm_campaign=identity-threat-detection-and-response&utm_source=thn&utm_medium=article&utm_term=jan24&utm_content=demo-cont-article)!


The result is that the discovery of the compromised account takes place only *after* the compromised machines are located and quarantined, and even then, it entails manually checking all the accounts that are logged there. And again – when racing against time, the dependency on manual and error-prone investigation creates a critical delay. 


### Identity IR Gap #2: No Playbook Move to Immediately Contain the Attack and Prevent Further Spread[#](#identity-ir-gap-2-no-playbook-move-to-immediately-contain-the-attack-and-prevent-further-spread)


As in real life, there's a stage of immediate first aid that precedes full treatment. The equivalent in the IR world is to contain the attack within its current boundaries and ensure it doesn't spread further, even prior to discovering its active components. On the network level, it's done by temporarily isolating segments that potentially host malicious activity from those that are not yet compromised. At the endpoint level, it's done by quarantining machines where malware is located.


Here again, the identity aspect needs to catch up. The only available containment is disabling the user account in AD or resetting its password. The first option is a no-go due to the operational disruption it introduces, especially in the case of false positives. The second option is not good either; if the suspected account is a machine-to-machine service account, resetting its password is likely to break the critical processes it manages, ending up with additional damage on top of the one the attack has caused. If the adversary has managed to compromise the identity infrastructure itself, resetting the password will be immediately addressed by shifting to another account.


### Identity IR Gap #3: No Playbook Move to Reduce Exposed Identity Attack Surfaces That Adversaries Target Within the Attack[#](#identity-ir-gap-3-no-playbook-move-to-reduce-exposed-identity-attack-surfaces-that-adversaries-target-within-the-attack)


The weaknesses that expose the identity attack surface to malicious credential access, privilege escalation, and lateral movement are blind spots for the posture and hygiene products in the security stack. This deprives the IR team of critical indications of compromise that could have significantly accelerated the process.


Prominent examples are vulnerable authentication protocols like NTLM (or, even worse, NTLMv1), misconfigurations like accounts set with unconstrained delegation, shadow admins, stale users, and many more. Adversaries feast on these weaknesses as they make their Living Off The Land route. The inability to locate and reconfigure or protect accounts and machines that feature these weaknesses turns the IR into a cat herding, where while the analyst is busy analyzing to see if Account A is compromised, the adversaries are already leveraging compromised Account B.

 ### Bottom Line: No Tools. No Shortcuts. Just Slow and Manual Log Analysis While the Attack is in Full Gear[#](#bottom-line-no-tools-no-shortcuts-just-slow-and-manual-log-analysis-while-the-attack-is-in-full-gear)


So, that's the status quo: when the IR team needs to finally discover who the compromised user accounts are that the attacker is using to spread in your environment. This is a secret no one talks about and the true root cause as to why lateral movement attacks are so successful and hard to contain, even when the IR process is taking place.


[**This is the challenge Silverfort solves**](https://www.silverfort.com/blog/the-identity-ir-playbook-against-scattered-spider-attacks/?utm_campaign=identity-threat-detection-and-response&utm_source=thn&utm_medium=article&utm_term=jan24&utm_content=ir-cont-article).


Silverfort Unified Identity Protection for IR Operations[#](#silverfort-unified-identity-protection-for-ir-operations)
----------------------------------------------------------------------------------------------------------------------


Silverfort's Unified Identity Protection platform integrates with the identity infrastructure on-prem and in the cloud (Active Directory, Entra ID, Okta, Ping, etc.). This integration enables Silverfort to have full visibility into any authentication and access attempt, real-time access enforcement to prevent malicious access with either MFA or access block, and automated discovery and protection of service accounts.


Let's see how these capabilities accelerate and optimize the identity IR process:


### Detection of Compromised Accounts with MFA with Zero Operational Disruption[#](#detection-of-compromised-accounts-with-mfa-with-zero-operational-disruption)


**Silverfort is the only solution that can enforce MFA protection on all AD authentication, including command line tools like PsExec and PowerShell.** With this capability, a single policy that requires all user accounts to verify their identity with MFA can detect all compromised accounts in minutes.


Once the policy is configured, the flow is simple:


1. The adversary attempts to continue its malicious access and logs into a machine with the account's compromised credentials.
2. The true user is prompted with MFA and denies that they have requested access to the specified resource.


**Goal #1 achieved: There's now evidence beyond doubt that this account is compromised.**


Side Note: Now that there's a validated compromised account, all we need to do is filter all the machines that this account has logged into in Silverfort's log screen.

 ### Contain the Attack with MFA and Block Access Policies [#](#contain-the-attack-with-mfa-and-block-access-policies)


The MFA policy we've described above not only serves to detect which accounts are compromised but also t**o prevent any additional spread of the attack**. This enables the IR team to freeze the adversary's foothold where it is and ensure that all the yet non-compromised resources stay intact.


### Protection with Operational Disruption Revisited: Zoom-in On Service Accounts[#](#protection-with-operational-disruption-revisited-zoomin-on-service-accounts)


Special attention should be given to service accounts as they are heavily abused by threat actors. These machine-to-machine accounts are not associated with a human user and cannot be subject to MFA protection.


However, Silverfort automatically discovers these accounts and gains insights into their repetitive behavioral patterns. With this visibility, Silverfort enables the configuration of policies that block access whenever a service account deviates from its behavior. In that manner, all of the standard service account activity is not disrupted, while any malicious attempt to abuse it is blocked.


**Goal #2 achieved: Attack is contained and the IR team can rapidly move to investigation**


### Eliminating Exposed Weaknesses in the Identity Attack Surface[#](#eliminating-exposed-weaknesses-in-the-identity-attack-surface)


Silverfort's visibility into all authentications and access attempts within the environment enables it to discover and mitigate common weaknesses that attackers take advantage of. Here are a few examples:


* Setting MFA policies for all shadow admins
* Setting block access policies for any NTLMv1 authentications
* Discover all accounts that were configured without pre-authentication
* Discover all accounts that were configured with unconstrained delegation


This attack surface reduction will usually take place during the initial' first aid' stage.


**Goal #3 achieved: Identity weaknesses are mitigated and cannot be used for malicious propagation.**


Conclusion: Gaining Identity IR Capabilities is Imperative - Are You Ready?[#](#conclusion-gaining-identity-ir-capabilities-is-imperative-are-you-ready)
--------------------------------------------------------------------------------------------------------------------------------------------------------


Compromised accounts are a key component in over 80% of cyber attacks, making the risk of getting hit an almost certainty. Security stakeholders should invest in having IR tools that can address this aspect in order to ensure their ability to respond efficiently when such an attack happens.


To learn more about the Silverfort platform's IR capabilities, [reach out](https://www.silverfort.com/request-a-demo/?utm_campaign=identity-threat-detection-and-response&utm_source=thn&utm_medium=article&utm_term=jan24&utm_content=demo-cont-article) to one of our experts to schedule a quick demo.


  





## Tags:


### Autogenerated tags:
silverfort mfa
