# Modernizing Vulnerability Management: The Move Toward Exposure Management
## Switch from traditional vulnerability management tools to exposure management for a better solution.
## Information:

+ Link: https://thehackernews.com/2023/04/modernizing-vulnerability-management.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 25 April 2023, 11:53
+ Date scraped: 25 April 2023, 12:00

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhjj8-N3pnt2cHgEi-Z5M3aDUvk0bwhf8sZoUMVJiQwat6NTsCErZ3yGhns9dRPrrtqYoVICritvTNhqwYSO6WFR9jtoQ8U22aa4eIUyi6ZlzTBTZN0hSYOZfQnibaQCa5iUHJWbKsTFS0Evmlp02HWDEqW5excBDpI1ldCR6rKKvmw78j4D_sWgMWx/s728-e3650/xmcyber.png)


Managing vulnerabilities in the constantly evolving technological landscape is a difficult task. Although vulnerabilities emerge regularly, not all vulnerabilities present the same level of risk. Traditional metrics such as CVSS score or the number of vulnerabilities are insufficient for effective vulnerability management as they lack business context, prioritization, and understanding of attackers' opportunities. Vulnerabilities only represent a small part of the attack surface that attackers can leverage.


Initially, organizations used manual methods to address known security weaknesses, but as technology and cyber threats evolved, a more automated and comprehensive approach became necessary. However, legacy vulnerability management tools were designed primarily for compliance and modern tools still face challenges in prioritization and limited resources, especially in dynamic and agile cloud environments.


Modern vulnerability management integrates security tools such as scanners, threat intelligence, and remediation workflows to provide a more efficient and effective solution. Nevertheless, organizations continue to face challenges such as:


* A growing list of vulnerabilities
* Inaccurate prioritization
* Missing business context
* Misalignment of priorities and resources between IT and security teams
* Lack of coverage and a unified view of risk


Exposures are broader than a typical CVE and can encompass more than just vulnerabilities. Exposures can result from various factors, such as human error, improperly defined security controls, and poorly designed and unsecured architecture. Many security tools tend to focus on specific types of exposures, such as vulnerabilities, misconfigurations, or identities, and address each one in isolation. However, this approach fails to consider how attackers view networks and systems. Attackers don't look at the individual exposure – rather, they leverage the [**toxic combination**](https://info.xmcyber.com/choke-points-the-new-approach-to-ultra-efficient-remediation?utm_source=hackernews&utm_medium=sponsorarticle&utm_campaign=vultoexpo) of vulnerabilities, misconfigurations, overly permissive identities, and other security gaps to move across systems and reach sensitive assets. This route is called an attack path and this type of lateral movement can go undetected for weeks or months, allowing attackers to cause significant and ongoing damage while hiding inside networks.


[![Vulnerability Management](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8Xw8AAoMBgDTD2qgAAAAASUVORK5CYII=)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgKzInLW4rq60GsClEgLNxFFEh_xjbYTrrlr72UWpNZrM-WQ-FIyUb7bYLjH3OJCkkB0QmSyDyTjttoujS4O2dbxL6H3VXZwQiGRIVfJYNdu06-GwPeNrE0PQFSOtJQoddUvLA1TiGxEnqT8nIZsfZqijx1rRRzRBZpyhkUiNGtng2aGdRkeWGkZfOG/s728-e365/xm-1.png)
A modern exposure management program involves combining multiple exposures onto an attack graph to understand the relationship and context of risk towards critical assets. This allows for targeted remediation that reduces risk in the most cost-efficient manner. To build a [**modern exposure management program**](https://info.xmcyber.com/exposure-management-guide?utm_source=hackernews&utm_medium=sponsorarticle&utm_campaign=vultoexpo), organizations should recognize the evolution of threat actors and their tactics, establish an operational process for ensuring continuous security posture improvement, and implement a plan consisting of remediation planning, remediation review, risk mitigation and mitigation verification. 


[![Vulnerability Management](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8Xw8AAoMBgDTD2qgAAAAASUVORK5CYII=)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhn_BGZxFY992A1C5kd6Gn6nejsu8hUk7sYk2Htt-JmJgPz-w1mr9M6drmVMGyz7qr5bpQlwSV21kRky_L5g-GJW3mmgANoIVv2oDRMKTblDMb8ydP0ljN8t8YEkv0HTmrNwhYPO313JpPu_VEmDXVsaGjXR6yWZHXlAzHaIjWeS4KbSETj-Os8siBZ/s728-e365/xm-2.png)
At XM Cyber, we believe that only by combining multiple exposures together onto an attack graph that visualizes all possible attack paths, can we understand the relationship and context of risk towards critical assets. And by understanding context, we can accurately prioritize issues to focus on the exposures that need remediating where they converge on [**choke points**](https://www.xmcyber.com/blog/why-focusing-on-choke-points-can-help-solve-your-resource-constraints?utm_source=hackernews&utm_medium=sponsorarticle&utm_campaign=vultoexpo). This allows for productive remediation that reduces risk in the most cost-efficient manner.


[![Vulnerability Management](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8Xw8AAoMBgDTD2qgAAAAASUVORK5CYII=)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiXlxrjWfpDphGXV8YwnPUljw3Bmdf5s0qCfWw7nGjPdOnYTN78yJa2_J6d3UOpYNbhKqgppe-m6SfhhtAhxrdpyBIyLw0VLbH29_gbTPS5qp7LaXV8JHtj45A0blSy07RYGcF3SLxHMwC3JfrHF6EMHX9vwaKhLUzY4Srw4jXb8e3AzU61u1s9bmrC/s728-e365/xm-3.png)
The three key pillars to building a modern exposure management program are:


* Understanding exposure insights - continuously identify and monitor potential risks to critical assets, as well as identifying any gaps in security controls or deviations from compliance standards.
* Analyzing attack paths - create an attack graph view that visualizes all possible attack paths to critical assets.
* Prioritizing remediation efforts - focus on the most critical issues and choke points that require immediate attention to reduce risk exposure in a cost-efficient manner.


By combining these three pillars, organizations can build a comprehensive and effective exposure management program that helps to protect critical assets and reduce overall risk exposure. This allows for productive remediation that reduces risk in the most cost-efficient manner. By continuously analyzing and monitoring exposures, organizations can build a sustainable and scalable process for managing risk over time.


***Note:** This article is written and contributed by Michael A. Greenberg, Director of Product Marketing at XM Cyber.*

 
\_linkedin\_partner\_id = "4481633";
window.\_linkedin\_data\_partner\_ids = window.\_linkedin\_data\_partner\_ids || [];
window.\_linkedin\_data\_partner\_ids.push(\_linkedin\_partner\_id);

(function(l) {
if (!l){window.lintrk = function(a,b){window.lintrk.q.push([a,b])};
window.lintrk.q=[]}
var s = document.getElementsByTagName("script")[0];
var b = document.createElement("script");
b.type = "text/javascript";b.async = true;
b.src = "https://snap.licdn.com/li.lms-analytics/insight.min.js";
s.parentNode.insertBefore(b, s);})(window.lintrk);


![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8Xw8AAoMBgDTD2qgAAAAASUVORK5CYII=)
 
 window.dataLayer = window.dataLayer || []; function gtag(){dataLayer.push(arguments);} gtag('js', new Date()); gtag('config', 'AW-10901628824');

  





## Tags:


### Autogenerated tags:
cost-efficient prioritization
