# Researchers Uncover New BGP Flaws in Popular Internet Routing Protocol Software
## Researchers have discovered vulnerabilities in the popular open-source internet routing protocol suite, FRRouting, that could be weaponized for DoS.
## Information:

+ Link: https://thehackernews.com/2023/05/researchers-uncover-new-bgp-flaws-in.html
+ Source: The Hacker News
+ Author: Ravie Lakshmanan
+ Date published: 02 May 2023, 14:26
+ Date scraped: 02 May 2023, 15:01

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEjhxtoI1HrhsOsFd4KcdFuNgCmn9GGMzaN1qVAS_7DkucVZl61kOAOtkOtafOLXnX6mnkL_98pOJxmHBacfybrgqVRQomNvV7LdSxhamPfcc6hBBroRZyWesxiUM-RBon6D93a22w8PWDBGvj8J7W9wAmz1BnJNqJJTxn0ndNlz6w8ie69JCM1xc3Ad/s728-e3650/map.png)


Cybersecurity researchers have uncovered weaknesses in a software implementation of the Border Gateway Protocol (BGP) that could be weaponized to achieve a denial-of-service (DoS) condition on vulnerable BGP peers.


The three vulnerabilities reside in version 8.4 of [FRRouting](https://github.com/FRRouting/frr), a popular open source internet routing protocol suite for Linux and Unix platforms. It's currently used by several vendors like [NVIDIA Cumulus](https://www.nvidia.com/en-us/networking/ethernet-switching/cumulus-linux/), [DENT](https://dent.dev/), and [SONiC](https://sonic-net.github.io/SONiC/), posing supply chain risks.


The discovery is the result of an analysis of seven different implementations of BGP carried out by Forescout Vedere Labs: FRRouting, BIRD, OpenBGPd, Mikrotik RouterOS, Juniper JunOS, Cisco IOS, and Arista EOS.


BGP is a [gateway protocol](https://www.cloudflare.com/learning/security/glossary/what-is-bgp/) that's designed to exchange routing and reachability information between autonomous systems. It's used to find the most efficient routes for delivering internet traffic.


The list of three flaws is as follows -


* [**CVE-2022-40302**](https://nvd.nist.gov/vuln/detail/cve-2022-40302) (CVSS score: 6.5) - Out-of-bounds read when processing a malformed [BGP OPEN message](https://www.ciscopress.com/articles/article.asp?p=2756480&seqNum=3) with an Extended Optional Parameters Length option.
* [**CVE-2022-40318**](https://nvd.nist.gov/vuln/detail/cve-2022-40318) (CVSS score: 6.5) - Out-of-bounds read when processing a malformed BGP OPEN message with an Extended Optional Parameters Length option.
* [**CVE-2022-43681**](https://nvd.nist.gov/vuln/detail/cve-2022-43681) (CVSS score: 6.5) - Out-of-bounds read when processing a malformed BGP OPEN message that abruptly ends with the option length octet.


The issues "could be exploited by attackers to achieve a DoS condition on vulnerable BGP peers, thus dropping all BGP sessions and routing tables and rendering the peer unresponsive," the company said in a [report](https://www.forescout.com/blog/three-new-bgp-message-parsing-vulnerabilities-disclosed-in-frrouting-software/) shared with The Hacker News.


[![BGP Vulnerabilities](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8Xw8AAoMBgDTD2qgAAAAASUVORK5CYII=)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhhqkRgfNE64NT5EbNdewcNp_TJSsAKolI_QOA6DRLw7pL7OmmqbSbXD4SogCWWI0NvOmHZcMb8KpCzekDC6KUQpup4WyKF9yKwSaqHZ-l2CJG_bj8FqkQYUzfhFTMzNLocb7B56g5c88pl2ToHtiVTmKFvoM53nJpzu9oZwpeWfluRIRRQJGJaY6Hm/s728-e365/chart.png)
"The DoS condition may be prolonged indefinitely by repeatedly sending malformed packets. The main root cause is the same vulnerable code pattern copied into several functions related to different stages of parsing OPEN messages."


A threat actor could spoof a valid IP address of a trusted BGP peer or exploit other flaws and misconfigurations to compromise a legitimate peer and then issue a specially-crafted unsolicited BGP OPEN message.


This is achieved by taking advantage of the fact that "FRRouting begins to process OPEN messages (e.g., decapsulating optional parameters) before it gets a chance to verify the BGP Identifier and ASN fields of the originating router."


Forescout has also made available an open source tool called [bgp\_boofuzzer](https://github.com/Forescout/bgp_boofuzzer/) that allows organizations to test the security of the BGP suites used internally as well as find new flaws in BGP implementations.


"Modern BGP implementations still have low-hanging fruits that can be abused by attackers," Forescout said. "To mitigate the risk of vulnerable BGP implementations, [...] the best recommendation is to patch network infrastructure devices as often as possible."


The findings come weeks after ESET found that secondhand [routers](https://www.cloudflare.com/learning/network-layer/what-is-a-router/) previously used in business networking environments harbored sensitive data, including corporate credentials, VPN details, cryptographic keys, and other vital customer information.


"In the wrong hands, the data gleaned from the devices – including customer data, router-to-router authentication keys, application lists, and much more – is enough to launch a cyberattack," the Slovak cybersecurity firm [said](https://www.eset.com/us/about/newsroom/press-releases/eset-discovers-corporate-secrets-and-data-on-recycled-company-routers-1/).



  





## Tags:
***CVE's***: CVE-2022-40318 CVE-2022-40302 CVE-2022-43681

### Autogenerated tags:
bgp frrouting forescout cvss out-of-bounds
